@@ -14,6 +14,8 @@ describe 'mistral::client' do
         :tag    => ['openstack', 'mistral-package']
       )
     end
+
+    it { is_expected.to contain_class('openstacklib::openstackclient') }
   end
 
   on_supported_os({
@@ -29,7 +31,15 @@ describe 'mistral::client' do
         when 'Debian'
           { :client_package => 'python3-mistralclient' }
         when 'RedHat'
-          { :client_package => 'python-mistralclient' }
+          if facts[:operatingsystem] == 'Fedora'
+            { :client_package => 'python3-mistralclient' }
+          else
+            if facts[:operatingsystemmajrelease] > '7'
+              { :client_package => 'python3-mistralclient' }
+            else
+              { :client_package => 'python-mistralclient' }
+            end
+          end
         end
       end
 
