@@ -5,7 +5,7 @@ describe 'mistral::policy' do
   shared_examples_for 'mistral policies' do
     let :params do
       {
-        :policy_path => '/etc/mistral/policy.json',
+        :policy_path => '/etc/mistral/policy.yaml',
         :policies    => {
           'context_is_admin' => {
             'key'   => 'context_is_admin',
@@ -17,13 +17,14 @@ describe 'mistral::policy' do
 
     it 'set up the policies' do
       is_expected.to contain_openstacklib__policy__base('context_is_admin').with({
-        :key        => 'context_is_admin',
-        :value      => 'foo:bar',
-        :file_user  => 'root',
-        :file_group => 'mistral',
+        :key         => 'context_is_admin',
+        :value       => 'foo:bar',
+        :file_user   => 'root',
+        :file_group  => 'mistral',
+        :file_format => 'yaml',
       })
       is_expected.to contain_oslo__policy('mistral_config').with(
-        :policy_file => '/etc/mistral/policy.json',
+        :policy_file => '/etc/mistral/policy.yaml',
       )
     end
   end
